==> ejc-sddjsorg-impl-3.0.0-20211020.020248-35-sources.jar: com/ejianc/business/production/bean/AcquisitionEquityEntity.java <==
package com.ejianc.business.production.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 产权登记-收购股权明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sddjsorg_production_acquisition_equity")
public class AcquisitionEquityEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private java.lang.Long pid; // 主表id
    @TableField(value="captail_name")
    private java.lang.String captailName; // 转让出资人名称
    @TableField(value="captail_type")
    private java.lang.String captailType; // 出资人类别
    @TableField(value="equity_proportion")
    private java.math.BigDecimal equityProportion; // 转让股权比例(%)
    @TableField(value="equity_price")
    private java.math.BigDecimal equityPrice; // 收购价格
    @TableField(value="equity_price_big")
    private java.lang.String equityPriceBig; // 收购价格(大写)
    @TableField(value="equity_assessment")
    private java.math.BigDecimal equityAssessment; // 收购股权的评估净产值
    @TableField(value="equity_assessment_big")
    private java.lang.String equityAssessmentBig; // 收购股权的评估净产值(大写)
    
    
    

    /**
     * 主表id
     */
    public java.lang.Long getPid() {
        return pid;
    }

    /**
     * 主表id
     */
    public void setPid(java.lang.Long pid) {
        this.pid = pid;
    }
    /**
     * 转让出资人名称
     */
    public java.lang.String getCaptailName() {
        return captailName;
    }

    /**
     * 转让出资人名称
     */
    public void setCaptailName(java.lang.String captailName) {
        this.captailName = captailName;
    }
    /**
     * 出资人类别
     */
    public java.lang.String getCaptailType() {
        return captailType;
    }

    /**
     * 出资人类别
     */
    public void setCaptailType(java.lang.String captailType) {
        this.captailType = captailType;
    }
    /**
     * 转让股权比例(%)
     */
    public java.math.BigDecimal getEquityProportion() {
        return equityProportion;
    }

    /**
     * 转让股权比例(%)
     */
    public void setEquityProportion(java.math.BigDecimal equityProportion) {
        this.equityProportion = equityProportion;
    }
    /**
     * 收购价格
     */
    public java.math.BigDecimal getEquityPrice() {
        return equityPrice;
    }

    /**
     * 收购价格
     */
    public void setEquityPrice(java.math.BigDecimal equityPrice) {
        this.equityPrice = equityPrice;
    }
    /**
     * 收购价格(大写)
     */
    public java.lang.String getEquityPriceBig() {
        return equityPriceBig;
    }

    /**
     * 收购价格(大写)
     */
    public void setEquityPriceBig(java.lang.String equityPriceBig) {
        this.equityPriceBig = equityPriceBig;
    }
    /**
     * 收购股权的评估净产值
     */
    public java.math.BigDecimal getEquityAssessment() {
        return equityAssessment;
    }

    /**
     * 收购股权的评估净产值
     */
    public void setEquityAssessment(java.math.BigDecimal equityAssessment) {
        this.equityAssessment = equityAssessment;
    }
    /**
     * 收购股权的评估净产值(大写)
     */
    public java.lang.String getEquityAssessmentBig() {
        return equityAssessmentBig;
    }

    /**
     * 收购股权的评估净产值(大写)
     */
    public void setEquityAssessmentBig(java.lang.String equityAssessmentBig) {
        this.equityAssessmentBig = equityAssessmentBig;
    }
    
}

==> ejc-sddjsorg-impl-3.0.0-20211025.071710-64-sources.jar: com/ejianc/business/production/bean/AcquisitionEquityEntity.java <==
package com.ejianc.business.production.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 产权登记-收购股权明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sddjsorg_production_acquisition_equity")
public class AcquisitionEquityEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private java.lang.Long pid; // 主表id
    @TableField(value="captail_name")
    private java.lang.String captailName; // 转让出资人名称
    @TableField(value="captail_type")
    private java.lang.String captailType; // 出资人类别
    @TableField(value="captail_type_id")
    private Long captailTypeId;
    @TableField(value="equity_proportion")
    private java.math.BigDecimal equityProportion; // 转让股权比例(%)
    @TableField(value="equity_price")
    private java.math.BigDecimal equityPrice; // 收购价格
    @TableField(value="equity_price_big")
    private java.lang.String equityPriceBig; // 收购价格(大写)
    @TableField(value="equity_assessment")
    private java.math.BigDecimal equityAssessment; // 收购股权的评估净产值
    @TableField(value="equity_assessment_big")
    private java.lang.String equityAssessmentBig; // 收购股权的评估净产值(大写)




    /**
     * 主表id
     */
    public java.lang.Long getPid() {
        return pid;
    }

    /**
     * 主表id
     */
    public void setPid(java.lang.Long pid) {
        this.pid = pid;
    }
    /**
     * 转让出资人名称
     */
    public java.lang.String getCaptailName() {
        return captailName;
    }

    /**
     * 转让出资人名称
     */
    public void setCaptailName(java.lang.String captailName) {
        this.captailName = captailName;
    }
    /**
     * 出资人类别
     */
    public java.lang.String getCaptailType() {
        return captailType;
    }

    /**
     * 出资人类别
     */
    public void setCaptailType(java.lang.String captailType) {
        this.captailType = captailType;
    }
    /**
     * 转让股权比例(%)
     */
    public java.math.BigDecimal getEquityProportion() {
        return equityProportion;
    }

    /**
     * 转让股权比例(%)
     */
    public void setEquityProportion(java.math.BigDecimal equityProportion) {
        this.equityProportion = equityProportion;
    }
    /**
     * 收购价格
     */
    public java.math.BigDecimal getEquityPrice() {
        return equityPrice;
    }

    /**
     * 收购价格
     */
    public void setEquityPrice(java.math.BigDecimal equityPrice) {
        this.equityPrice = equityPrice;
    }
    /**
     * 收购价格(大写)
     */
    public java.lang.String getEquityPriceBig() {
        return equityPriceBig;
    }

    /**
     * 收购价格(大写)
     */
    public void setEquityPriceBig(java.lang.String equityPriceBig) {
        this.equityPriceBig = equityPriceBig;
    }
    /**
     * 收购股权的评估净产值
     */
    public java.math.BigDecimal getEquityAssessment() {
        return equityAssessment;
    }

    /**
     * 收购股权的评估净产值
     */
    public void setEquityAssessment(java.math.BigDecimal equityAssessment) {
        this.equityAssessment = equityAssessment;
    }
    /**
     * 收购股权的评估净产值(大写)
     */
    public java.lang.String getEquityAssessmentBig() {
        return equityAssessmentBig;
    }

    /**
     * 收购股权的评估净产值(大写)
     */
    public void setEquityAssessmentBig(java.lang.String equityAssessmentBig) {
        this.equityAssessmentBig = equityAssessmentBig;
    }

    public Long getCaptailTypeId() {
        return captailTypeId;
    }

    public void setCaptailTypeId(Long captailTypeId) {
        this.captailTypeId = captailTypeId;
    }
}
